@@ -1,11 +1,15 @@
+from typing import Dict, Any, Optional
+
+
 class ViewState:
-    def __init__(self, original_author_id, menu_type, raw_query, extra_state=None):
+    def __init__(self, original_author_id: int, menu_type: str, raw_query: str,
+                 extra_state: Optional[Dict[str, Any]] = None):
         self.extra_state = extra_state or {}
         self.menu_type = menu_type
         self.original_author_id = original_author_id
         self.raw_query = raw_query
 
-    def serialize(self):
+    def serialize(self) -> Dict[str, Any]:
         ret = {
             'raw_query': self.raw_query,
             'menu_type': self.menu_type,
